@@ -354,8 +354,14 @@ def _get_any(context, path, content, type, mimetype, format, decode):
     print(response)
     file_bytes = response['Body']
     last_modified_str = response['LastModified']
-    last_modified = datetime.datetime.strptime(
-        last_modified_str, "%a, %d %b %Y %H:%M:%S GMT")
+    if not isinstance(last_modified_str, str):
+        last_modified = f"{datetime.datetime.now():%a, %d %b %Y %H:%M:%S GMT}"
+    else:
+        last_modified = datetime.datetime.strptime(
+        last_modified_str, "%Y-%m-%dT%H:%M:%S.%fZ")
+    # last_modified_str = response['LastModified']
+    # last_modified = datetime.datetime.strptime(
+    #     last_modified_str, "%a, %d %b %Y %H:%M:%S GMT")
     return {
         'name': _final_path_component(path),
         'path': path,
